@@ -1,7 +1,8 @@
 """Serializer for Circuit Maintenance API."""
 from rest_framework import serializers
+from nautobot.circuits.api.nested_serializers import NestedProviderSerializer
 from nautobot.circuits.api.serializers import CircuitSerializer
-from nautobot_circuit_maintenance.models import CircuitImpact, CircuitMaintenance, Note
+from nautobot_circuit_maintenance.models import CircuitImpact, CircuitMaintenance, Note, NotificationSource
 
 
 class CircuitMaintenanceCircuitImpactSerializer(serializers.ModelSerializer):
@@ -38,3 +39,18 @@ class NoteSerializer(serializers.ModelSerializer):
 
         model = Note
         fields = ["id", "maintenance", "title", "comment"]
+
+
+class NotificationSourceSerializer(serializers.ModelSerializer):
+    """Serializer for NotificationSource records."""
+
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:nautobot_circuit_maintenance-api:notificationsource-detail"
+    )
+    providers = NestedProviderSerializer(many=True)
+
+    class Meta:
+        """Meta class for NotificationSourceSerializer."""
+
+        model = NotificationSource
+        fields = ["id", "url", "name", "slug", "providers", "attach_all_providers"]
